<!DOCTYPE html>
<html>
<head>
  <title>PyaaS - {% block title %}Main{% end %}</title>
  <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
  <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap-theme.min.css">
  {% block head %}{% end %}
  {% block templates %}{% end %}
</head>
<body>
  {% block body %}<a href="/main">Authenticate</a>{% end %}
  <script src="//code.jquery.com/jquery-2.1.1.min.js"></script>
  <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
  <script src="//cdnjs.cloudflare.com/ajax/libs/backbone.js/1.1.2/backbone-min.js"></script>
  <script src="//cdnjs.cloudflare.com/ajax/libs/underscore.js/1.6.0/underscore-min.js"></script>
  {% block scripts %}{% end %}
</body>
</html>
